@@ -244,3 +244,9 @@ tidy.step_timeseries_signature <- function(x, ...) {
     res$id <- x$id
     tibble::as_tibble(res)
 }
+
+#' @rdname required_pkgs.timetk
+#' @export
+required_pkgs.step_timeseries_signature <- function(x, ...) {
+    c("timetk")
+}
